@@ -1,8 +1,9 @@
+import aiohttp
 import pytest
 from seleniumwire import webdriver
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def driver():
     options = webdriver.ChromeOptions()
     options.add_argument("headless")
@@ -16,6 +17,12 @@ def driver():
         driver.quit()
 
 
+@pytest.fixture
+async def session():
+    async with aiohttp.ClientSession() as session:
+        yield session
+
+
 @pytest.mark.asyncio
-async def test_selenium(driver) -> None:
+async def test_selenium(driver, session) -> None:
     driver.get("https://www.google.com/")
